#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-cabal-plugin-2.3.0.0-19uSBLYJ42u3M1cH93FFhL
key:                  hls-cabal-plugin-2.3.0.0-19uSBLYJ42u3M1cH93FFhL
license:              MIT
maintainer:           fendor@posteo.de
author:               Fendor
synopsis:             Cabal integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4abc29d18fc2eb4eb6ce6577cfc4d184
exposed:              True
exposed-modules:
    Ide.Plugin.Cabal Ide.Plugin.Cabal.Completion.Completer.FilePath
    Ide.Plugin.Cabal.Completion.Completer.Module
    Ide.Plugin.Cabal.Completion.Completer.Paths
    Ide.Plugin.Cabal.Completion.Completer.Simple
    Ide.Plugin.Cabal.Completion.Completer.Snippet
    Ide.Plugin.Cabal.Completion.Completer.Types
    Ide.Plugin.Cabal.Completion.Completions
    Ide.Plugin.Cabal.Completion.Data Ide.Plugin.Cabal.Completion.Types
    Ide.Plugin.Cabal.Diagnostics Ide.Plugin.Cabal.LicenseSuggest
    Ide.Plugin.Cabal.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-plugin
hs-libraries:         HShls-cabal-plugin-2.3.0.0-19uSBLYJ42u3M1cH93FFhL
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1 directory-1.3.8.5
    extra-1.7.16-HTBQCN3DO2zH7sDTaOIuTE filepath-1.4.300.1
    ghcide-2.3.0.0-4R1g1D1U7t93kdyACXpUJR
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    hls-graph-2.3.0.0-1y0dg6p7D1lASOU6QbZ8pB
    hls-plugin-api-2.3.0.0-9v1CHhN0g86FDoNzaIbW5k
    lens-5.3.4-4Gn3x9DAN5U4gsnCQbhlSx
    lsp-2.2.0.0-Hz1OJxM2hEY9bIY7nXebtz
    lsp-types-2.0.2.0-AX0hlEXShAUGb8u04DcV0I
    regex-tdfa-1.3.2.5-2Z48wQLqPnRDongr7ozo6M stm-2.5.1.0 text-2.0.2
    text-rope-0.3-13PtxrxbfWSEznkenTV65t transformers-0.6.1.0
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-plugin/html/hls-cabal-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

